local mod = ...



-- Spawn orientations
local orientationMin = { 0, 0, 0, 1 }
local orientationMax = { 0, 0, 0, 1 }
quaternion.setEulerAngles(orientationMin, { 0, -180, 0 })
quaternion.setEulerAngles(orientationMax, { 0, 180, 0 })


-- registering map files
mod:registerAssetId("maps/heightmap.png", "HEIGHT_MAP")
mod:registerAssetId("maps/material_mask.png", "MATERIAL_MASK")
mod:registerAssetId("maps/rock_density.png", "ROCK_DENSITY_MAP")
mod:registerAssetId("maps/fish_density.png", "FISH_DENSITY_MAP")
mod:registerAssetId("maps/tree_density_map1.png", "TREE_DENSITY_MAP1")
mod:registerAssetId("maps/tree_density_map2.png", "TREE_DENSITY_MAP2")
mod:registerAssetId("maps/tree_density_map3.png", "TREE_DENSITY_MAP3")


-- register custom map
mod:registerAsset({
	DataType = "CUSTOM_MAP",
	Id = "MAP_SAOVICENTE",
	HeightMap = "HEIGHT_MAP",
	MaterialMask = "MATERIAL_MASK",
	MinHeight = -4,
	MaxHeight = 88,
	VillagePathList = {
		{
			Entrance = { 720, 0, 603 },
			Exit = { 762, 0, 339 },
		},
		{
			Entrance = { 221, 0, 290 },
			Exit = { 725, 0, 613 },
		},
		{
			Entrance = { 521, 0, 841 },
			Exit = { 120, 0, 419 },
		},
		{
			Entrance = { 510, 0, 841 },
			Exit = { 421, 0, 187 },
		},
		{
			Entrance = { 112, 0, 435 },
			Exit = { 733, 0, 610 },
		}
	},
	SpawnList = {
		{
			Prefab = "PREFAB_MINERAL_SOURCE_1",
            Position = { 865, 6, 459 },
            Orientation = { 0 , 60, 0 },
        },
		{
			Prefab = "PREFAB_MINERAL_SOURCE_2",
            Position = { 661, 7, 750 },
            Orientation = { 0 , 28, 0 },
        },
		{
			Prefab = "PREFAB_MINERAL_SOURCE_3",
            Position = { 254, 10, 341 },
            Orientation = { 0 , 93, 0 },
        },
		{
			Prefab = "PREFAB_MINERAL_SOURCE_1",
            Position = { 183, 7, 599 },
            Orientation = { 0 , -67, 0 },
        },
		{
			Prefab = "PREFAB_MINERAL_SOURCE_2",
            Position = { 471, 6, 760 },
            Orientation = { 0 , -141, 0 },
        },
		{
			Prefab = "PREFAB_MINERAL_SOURCE_3",
            Position = { 590, 20, 267 },
            Orientation = { 0 , -116, 0 },
        },
	},
	DensitySpawnList = {
        {
			DensityMap = "TREE_DENSITY_MAP1",
			Density = 0.8,
			PrefabConfigList = {
				{
                    PrefabList = { "PREFAB_TROPICAL_TREE_PALM1" },
                    RandomWeight = 5.0,
                    OffsetSizeRange = {
                        Min = 0.75,
                        Max = 1.35
                    },
                        OrientationRange = {
                            Min = orientationMin,
                            Max = orientationMax,
                    },
                        ScaleRange = {
                            Min = 0.7,
                            Max = 1.3
                    },
                        ColorRange = {
                            Min = { 0.55, 0.55, 0.60, 1 },
                            Max = { 0.65, 0.65, 0.80, 1 }
                    }
				},
				{
                    PrefabList = { "PREFAB_TROPICAL_TREE_PALM2" },
                    RandomWeight = 5.0,
                    OffsetSizeRange = {
                        Min = 0.75,
                        Max = 1.75
                    },
                        OrientationRange = {
                            Min = orientationMin,
                            Max = orientationMax,
                    },
                        ScaleRange = {
                            Min = 0.9,
                            Max = 1.1
                    },
                        ColorRange = {
                            Min = { 0.55, 0.55, 0.72, 1 },
                            Max = { 0.65, 0.65, 0.72, 1 }
                    }
				},
				{
                    PrefabList = { "PREFAB_TROPICAL_TREE_DATE" },
                    RandomWeight = 0.25,
                    OffsetSizeRange = {
                        Min = 0.90,
                        Max = 1.10
                    },
                        OrientationRange = {
                            Min = orientationMin,
                            Max = orientationMax,
                    },
                        ScaleRange = {
                            Min = 0.9,
                            Max = 1.1
                    },
                        ColorRange = {
                            Min = { 0.55, 0.55, 0.72, 1 },
                            Max = { 0.65, 0.65, 0.72, 1 }
                    }
				},
				{
                    PrefabList = { "PREFAB_TROPICAL_TREE_CANE" },
                    RandomWeight = 2.5,
                    OffsetSizeRange = {
                        Min = 0.85,
                        Max = 1.15
                    },
                        OrientationRange = {
                            Min = orientationMin,
                            Max = orientationMax,
                    },
                        ScaleRange = {
                            Min = 0.7,
                            Max = 1.3
                    },
                        ColorRange = {
                            Min = { 0.55, 0.55, 0.72, 1 },
                            Max = { 0.65, 0.65, 0.72, 1 }
                    }
				},
				-- {
                --     PrefabList = { "PREFAB_TREE_PINE" },
                --     RandomWeight = 2.5,
                --     OffsetSizeRange = {
                --         Min = 0.85,
                --         Max = 1.15
                --     },
                --         OrientationRange = {
                --             Min = orientationMin,
                --             Max = orientationMax,
                --     },
                --         ScaleRange = {
                --             Min = 0.7,
                --             Max = 1.3
                --     },
                --         ColorRange = {
                --             Min = { 0.55, 0.55, 0.72, 1 },
                --             Max = { 0.65, 0.65, 0.72, 1 }
                --     }
				-- },
            },
		},
        {
			DensityMap = "TREE_DENSITY_MAP2",
			Density = 0.7,
			PrefabConfigList = {
				{
                    PrefabList = { "PREFAB_TROPICAL_TREE_DATE" },
                    RandomWeight = 0.5,
                    OffsetSizeRange = {
                        Min = 0.90,
                        Max = 1.10
                    },
                        OrientationRange = {
                            Min = orientationMin,
                            Max = orientationMax,
                    },
                        ScaleRange = {
                            Min = 0.9,
                            Max = 1.1
                    },
                        ColorRange = {
                            Min = { 0.55, 0.55, 0.72, 1 },
                            Max = { 0.65, 0.65, 0.72, 1 }
                    }
				},
				{
                    PrefabList = { "PREFAB_TROPICAL_TREE_CANE" },
                    RandomWeight = 10,
                    OffsetSizeRange = {
                        Min = 0.85,
                        Max = 1.15
                    },
                        OrientationRange = {
                            Min = orientationMin,
                            Max = orientationMax,
                    },
                        ScaleRange = {
                            Min = 0.7,
                            Max = 1.3
                    },
                        ColorRange = {
                            Min = { 0.55, 0.55, 0.72, 1 },
                            Max = { 0.65, 0.65, 0.72, 1 }
                    }
				},
				{
                    PrefabList = { "PREFAB_TROPICAL_TREE_PALM2" },
                    RandomWeight = 0.10,
                    OffsetSizeRange = {
                        Min = 0.85,
                        Max = 1.15
                    },
                        OrientationRange = {
                            Min = orientationMin,
                            Max = orientationMax,
                    },
                        ScaleRange = {
                            Min = 0.7,
                            Max = 1.3
                    },
                        ColorRange = {
                            Min = { 0.55, 0.55, 0.72, 1 },
                            Max = { 0.65, 0.65, 0.72, 1 }
                    }
				},
                {
                    PrefabList = { "PREFAB_TROPICAL_FLOWER1" },
                    RandomWeight = 3.0,
                    OffsetSizeRange = {
                        Min = 0.85,
                        Max = 1.15
                    },
                        OrientationRange = {
                            Min = orientationMin,
                            Max = orientationMax,
                    },
                        ScaleRange = {
                            Min = 0.7,
                            Max = 1.3
                    },
                        ColorRange = {
                            Min = { 0.55, 0.55, 0.72, 1 },
                            Max = { 0.65, 0.65, 0.72, 1 }
                    }
				},
                {
                    PrefabList = { "PREFAB_TROPICAL_FLOWER2" },
                    RandomWeight = 2.5,
                    OffsetSizeRange = {
                        Min = 0.85,
                        Max = 1.15
                    },
                        OrientationRange = {
                            Min = orientationMin,
                            Max = orientationMax,
                    },
                        ScaleRange = {
                            Min = 0.7,
                            Max = 1.3
                    },
                        ColorRange = {
                            Min = { 0.55, 0.55, 0.72, 1 },
                            Max = { 0.65, 0.65, 0.72, 1 }
                    }
				},
                {
                    PrefabList = { "PREFAB_TROPICAL_FLOWER3" },
                    RandomWeight = 2.5,
                    OffsetSizeRange = {
                        Min = 0.85,
                        Max = 1.15
                    },
                        OrientationRange = {
                            Min = orientationMin,
                            Max = orientationMax,
                    },
                        ScaleRange = {
                            Min = 0.7,
                            Max = 1.3
                    },
                        ColorRange = {
                            Min = { 0.55, 0.55, 0.72, 1 },
                            Max = { 0.65, 0.65, 0.72, 1 }
                    }
				},
                {
                    PrefabList = { "PREFAB_TROPICAL_FLOWER4" },
                    RandomWeight = 2.5,
                    OffsetSizeRange = {
                        Min = 0.85,
                        Max = 1.15
                    },
                        OrientationRange = {
                            Min = orientationMin,
                            Max = orientationMax,
                    },
                        ScaleRange = {
                            Min = 0.7,
                            Max = 1.3
                    },
                        ColorRange = {
                            Min = { 0.55, 0.55, 0.72, 1 },
                            Max = { 0.65, 0.65, 0.72, 1 }
                    }
				},
            },
		},
        {
			DensityMap = "TREE_DENSITY_MAP3",
			Density = 0.9,
			PrefabConfigList = {
                {
                    PrefabList = { "PREFAB_TROPICAL_FLOWER1" },
                    RandomWeight = 2.0,
                    OffsetSizeRange = {
                        Min = 0.85,
                        Max = 1.15
                    },
                        OrientationRange = {
                            Min = orientationMin,
                            Max = orientationMax,
                    },
                        ScaleRange = {
                            Min = 0.7,
                            Max = 1.3
                    },
                        ColorRange = {
                            Min = { 0.55, 0.55, 0.72, 1 },
                            Max = { 0.65, 0.65, 0.72, 1 }
                    }
				},
                {
                    PrefabList = { "PREFAB_TROPICAL_FLOWER2" },
                    RandomWeight = 1.5,
                    OffsetSizeRange = {
                        Min = 0.85,
                        Max = 1.15
                    },
                        OrientationRange = {
                            Min = orientationMin,
                            Max = orientationMax,
                    },
                        ScaleRange = {
                            Min = 0.7,
                            Max = 1.3
                    },
                        ColorRange = {
                            Min = { 0.55, 0.55, 0.72, 1 },
                            Max = { 0.65, 0.65, 0.72, 1 }
                    }
				},
                {
                    PrefabList = { "PREFAB_TROPICAL_FLOWER3" },
                    RandomWeight = 1.5,
                    OffsetSizeRange = {
                        Min = 0.85,
                        Max = 1.15
                    },
                        OrientationRange = {
                            Min = orientationMin,
                            Max = orientationMax,
                    },
                        ScaleRange = {
                            Min = 0.7,
                            Max = 1.3
                    },
                        ColorRange = {
                            Min = { 0.55, 0.55, 0.72, 1 },
                            Max = { 0.65, 0.65, 0.72, 1 }
                    }
				},
                {
                    PrefabList = { "PREFAB_TROPICAL_FLOWER4" },
                    RandomWeight = 1.5,
                    OffsetSizeRange = {
                        Min = 0.85,
                        Max = 1.15
                    },
                        OrientationRange = {
                            Min = orientationMin,
                            Max = orientationMax,
                    },
                        ScaleRange = {
                            Min = 0.7,
                            Max = 1.3
                    },
                        ColorRange = {
                            Min = { 0.55, 0.55, 0.72, 1 },
                            Max = { 0.65, 0.65, 0.72, 1 }
                    }
				},
            },
		},
        {
			-- Create rock outcrops - stone resource
			DensityMap = "ROCK_DENSITY_MAP",
			Density =0.9,
			PrefabConfigList = {
				{
						PrefabList = { "PREFAB_RESOURCE_ROCK" },
						RandomWeight = 0.1,
						OffsetSizeRange = {
							Min = 0.75,
							Max = 1.0
					},
						OrientationRange = {
							Min = orientationMin,
							Max = orientationMax,
					},
						ScaleRange = {
							Min = 0.85,
							Max = 1.15
					},
						ColorRange = {
							Min = { 0.8, 0.8, 0.8, 1 },
							Max = { 1, 1, 1, 1 }
					}
				}
			}
		},
		{
			-- Create fish shoals
			DensityMap = "FISH_DENSITY_MAP",
			Density =0.9,
			PrefabConfigList = {
				{
						PrefabList = { "PREFAB_RESOURCE_FISH" },
						RandomWeight = 0.1,
						OffsetSizeRange = {
							Min = 0.75,
							Max = 1.0
					},
						OrientationRange = {
							Min = { 0, -180, 0 },
							Max = { 0, 180, 0 }
					},
						ScaleRange = {
							Min = 0.85,
							Max = 1.15
					},
						ColorRange = {
							Min = { 0.8, 0.8, 0.8, 1 },
							Max = { 1, 1, 1, 1 }
					}
				}
			}
		},
	},
})
-- This map was created with the help of the UFME
